@@ -34,3 +34,9 @@ class HolodexHttpClient:
 
     async def search_autocomplete(self, q: str) -> Any:
         return await self.request("GET", f"/search/autocomplete", params={"q": q})
+
+    async def live(
+        self,
+        org: Literal["All Vtubers", "Hololive", "Nijisanji", "Independents"],
+    ) -> Any:
+        return await self.request("GET", f"/live", params={"org": org})
